==> monaco-vscode-view-common-service-override-4.5.1.tgz: package/vscode/src/vs/workbench/contrib/customEditor/common/extensionPoint.js <==
import { coalesce } from 'vscode/vscode/vs/base/common/arrays';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { Extensions } from 'vscode/vscode/vs/workbench/services/extensionManagement/common/extensionFeatures';
import { ExtensionsRegistry } from 'vscode/vscode/vs/workbench/services/extensions/common/extensionsRegistry';
import { languagesExtPoint } from 'vscode/vscode/vs/workbench/services/language/common/languageService';

const Fields = ( Object.freeze({
    viewType: 'viewType',
    displayName: 'displayName',
    selector: 'selector',
    priority: 'priority',
}));
const CustomEditorsContribution = {
    description: ( localizeWithPath(
        'vs/workbench/contrib/customEditor/common/extensionPoint',
        'contributes.customEditors',
        'Contributed custom editors.'
    )),
    type: 'array',
    defaultSnippets: [{
            body: [{
                    [Fields.viewType]: '$1',
                    [Fields.displayName]: '$2',
                    [Fields.selector]: [{
                            filenamePattern: '$3'
                        }],
                }]
        }],
    items: {
        type: 'object',
        required: [
            Fields.viewType,
            Fields.displayName,
            Fields.selector,
        ],
        properties: {
            [Fields.viewType]: {
                type: 'string',
                markdownDescription: ( localizeWithPath(
                    'vs/workbench/contrib/customEditor/common/extensionPoint',
                    'contributes.viewType',
                    'Identifier for the custom editor. This must be unique across all custom editors, so we recommend including your extension id as part of `viewType`. The `viewType` is used when registering custom editors with `vscode.registerCustomEditorProvider` and in the `onCustomEditor:${id}` [activation event](https://code.visualstudio.com/api/references/activation-events).'
                )),
            },
            [Fields.displayName]: {
                type: 'string',
                description: ( localizeWithPath(
                    'vs/workbench/contrib/customEditor/common/extensionPoint',
                    'contributes.displayName',
                    'Human readable name of the custom editor. This is displayed to users when selecting which editor to use.'
                )),
            },
            [Fields.selector]: {
                type: 'array',
                description: ( localizeWithPath(
                    'vs/workbench/contrib/customEditor/common/extensionPoint',
                    'contributes.selector',
                    'Set of globs that the custom editor is enabled for.'
                )),
                items: {
                    type: 'object',
                    defaultSnippets: [{
                            body: {
                                filenamePattern: '$1',
                            }
                        }],
                    properties: {
                        filenamePattern: {
                            type: 'string',
                            description: ( localizeWithPath(
                                'vs/workbench/contrib/customEditor/common/extensionPoint',
                                'contributes.selector.filenamePattern',
                                'Glob that the custom editor is enabled for.'
                            )),
                        },
                    }
                }
            },
            [Fields.priority]: {
                type: 'string',
                markdownDeprecationMessage: ( localizeWithPath(
                    'vs/workbench/contrib/customEditor/common/extensionPoint',
                    'contributes.priority',
                    'Controls if the custom editor is enabled automatically when the user opens a file. This may be overridden by users using the `workbench.editorAssociations` setting.'
                )),
                enum: [
                    "default" ,
                    "option" ,
                ],
                markdownEnumDescriptions: [
                    ( localizeWithPath(
                        'vs/workbench/contrib/customEditor/common/extensionPoint',
                        'contributes.priority.default',
                        'The editor is automatically used when the user opens a resource, provided that no other default custom editors are registered for that resource.'
                    )),
                    ( localizeWithPath(
                        'vs/workbench/contrib/customEditor/common/extensionPoint',
                        'contributes.priority.option',
                        'The editor is not automatically used when the user opens a resource, but a user can switch to the editor using the `Reopen With` command.'
                    )),
                ],
                default: 'default'
            }
        }
    }
};
const customEditorsExtensionPoint = ExtensionsRegistry.registerExtensionPoint({
    extensionPoint: 'customEditors',
    deps: [languagesExtPoint],
    jsonSchema: CustomEditorsContribution,
    activationEventsGenerator: (contribs, result) => {
        for (const contrib of contribs) {
            const viewType = contrib[Fields.viewType];
            if (viewType) {
                result.push(`onCustomEditor:${viewType}`);
            }
        }
    },
});
class CustomEditorsDataRenderer extends Disposable {
    constructor() {
        super(...arguments);
        this.type = 'table';
    }
    shouldRender(manifest) {
        return !!manifest.contributes?.customEditors;
    }
    render(manifest) {
        const customEditors = manifest.contributes?.customEditors || [];
        if (!customEditors.length) {
            return { data: { headers: [], rows: [] }, dispose: () => { } };
        }
        const headers = [
            ( localizeWithPath(
                'vs/workbench/contrib/customEditor/common/extensionPoint',
                'customEditors view type',
                "View Type"
            )),
            ( localizeWithPath(
                'vs/workbench/contrib/customEditor/common/extensionPoint',
                'customEditors priority',
                "Priority"
            )),
            ( localizeWithPath(
                'vs/workbench/contrib/customEditor/common/extensionPoint',
                'customEditors filenamePattern',
                "Filename Pattern"
            )),
        ];
        const rows = ( customEditors
            .map(customEditor => {
            return [
                customEditor.viewType,
                customEditor.priority ?? '',
                coalesce(( customEditor.selector.map(x => x.filenamePattern))).join(', ')
            ];
        }));
        return {
            data: {
                headers,
                rows
            },
            dispose: () => { }
        };
    }
}
( Registry.as(Extensions.ExtensionFeaturesRegistry)).registerExtensionFeature({
    id: 'customEditors',
    label: ( localizeWithPath(
        'vs/workbench/contrib/customEditor/common/extensionPoint',
        'customEditors',
        "Custom Editors"
    )),
    access: {
        canToggle: false
    },
    renderer: ( new SyncDescriptor(CustomEditorsDataRenderer)),
});

export { customEditorsExtensionPoint };

==> monaco-vscode-view-common-service-override-5.1.0.tgz: package/vscode/src/vs/workbench/contrib/customEditor/common/extensionPoint.js <==
import { coalesce } from 'vscode/vscode/vs/base/common/arrays';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { Extensions } from 'vscode/vscode/vs/workbench/services/extensionManagement/common/extensionFeatures';
import { ExtensionsRegistry } from 'vscode/vscode/vs/workbench/services/extensions/common/extensionsRegistry';
import { languagesExtPoint } from 'vscode/vscode/vs/workbench/services/language/common/languageService';

const _moduleId = "vs/workbench/contrib/customEditor/common/extensionPoint";
const Fields = ( (Object.freeze({
    viewType: 'viewType',
    displayName: 'displayName',
    selector: 'selector',
    priority: 'priority',
})));
const CustomEditorsContribution = {
    description: ( localizeWithPath(_moduleId, 0, 'Contributed custom editors.')),
    type: 'array',
    defaultSnippets: [{
            body: [{
                    [Fields.viewType]: '$1',
                    [Fields.displayName]: '$2',
                    [Fields.selector]: [{
                            filenamePattern: '$3'
                        }],
                }]
        }],
    items: {
        type: 'object',
        required: [
            Fields.viewType,
            Fields.displayName,
            Fields.selector,
        ],
        properties: {
            [Fields.viewType]: {
                type: 'string',
                markdownDescription: ( localizeWithPath(
                    _moduleId,
                    1,
                    'Identifier for the custom editor. This must be unique across all custom editors, so we recommend including your extension id as part of `viewType`. The `viewType` is used when registering custom editors with `vscode.registerCustomEditorProvider` and in the `onCustomEditor:${id}` [activation event](https://code.visualstudio.com/api/references/activation-events).'
                )),
            },
            [Fields.displayName]: {
                type: 'string',
                description: ( localizeWithPath(
                    _moduleId,
                    2,
                    'Human readable name of the custom editor. This is displayed to users when selecting which editor to use.'
                )),
            },
            [Fields.selector]: {
                type: 'array',
                description: ( localizeWithPath(_moduleId, 3, 'Set of globs that the custom editor is enabled for.')),
                items: {
                    type: 'object',
                    defaultSnippets: [{
                            body: {
                                filenamePattern: '$1',
                            }
                        }],
                    properties: {
                        filenamePattern: {
                            type: 'string',
                            description: ( localizeWithPath(_moduleId, 4, 'Glob that the custom editor is enabled for.')),
                        },
                    }
                }
            },
            [Fields.priority]: {
                type: 'string',
                markdownDeprecationMessage: ( localizeWithPath(
                    _moduleId,
                    5,
                    'Controls if the custom editor is enabled automatically when the user opens a file. This may be overridden by users using the `workbench.editorAssociations` setting.'
                )),
                enum: [
                    "default" ,
                    "option" ,
                ],
                markdownEnumDescriptions: [
                    ( localizeWithPath(
                        _moduleId,
                        6,
                        'The editor is automatically used when the user opens a resource, provided that no other default custom editors are registered for that resource.'
                    )),
                    ( localizeWithPath(
                        _moduleId,
                        7,
                        'The editor is not automatically used when the user opens a resource, but a user can switch to the editor using the `Reopen With` command.'
                    )),
                ],
                default: 'default'
            }
        }
    }
};
const customEditorsExtensionPoint = ExtensionsRegistry.registerExtensionPoint({
    extensionPoint: 'customEditors',
    deps: [languagesExtPoint],
    jsonSchema: CustomEditorsContribution,
    activationEventsGenerator: (contribs, result) => {
        for (const contrib of contribs) {
            const viewType = contrib[Fields.viewType];
            if (viewType) {
                result.push(`onCustomEditor:${viewType}`);
            }
        }
    },
});
class CustomEditorsDataRenderer extends Disposable {
    constructor() {
        super(...arguments);
        this.type = 'table';
    }
    shouldRender(manifest) {
        return !!manifest.contributes?.customEditors;
    }
    render(manifest) {
        const customEditors = manifest.contributes?.customEditors || [];
        if (!customEditors.length) {
            return { data: { headers: [], rows: [] }, dispose: () => { } };
        }
        const headers = [
            ( localizeWithPath(_moduleId, 8, "View Type")),
            ( localizeWithPath(_moduleId, 9, "Priority")),
            ( localizeWithPath(_moduleId, 10, "Filename Pattern")),
        ];
        const rows = ( (customEditors
            .map(customEditor => {
            return [
                customEditor.viewType,
                customEditor.priority ?? '',
                coalesce(( (customEditor.selector.map(x => x.filenamePattern)))).join(', ')
            ];
        })));
        return {
            data: {
                headers,
                rows
            },
            dispose: () => { }
        };
    }
}
( (Registry.as(Extensions.ExtensionFeaturesRegistry))).registerExtensionFeature({
    id: 'customEditors',
    label: ( localizeWithPath(_moduleId, 11, "Custom Editors")),
    access: {
        canToggle: false
    },
    renderer: ( (new SyncDescriptor(CustomEditorsDataRenderer))),
});

export { customEditorsExtensionPoint };
